==> cramr_ui_lib-0.0.5.tar.gz: lib/routes/verb_indicative_study_flashcard_mode_form_state.dart <==
import 'dart:async';

import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_form_appbar.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_route.dart';
import 'package:cramr_ui_lib/theme/custom_theme.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class VerbIndicativeStudyFlashcardModeFormState
    extends State<VerbIndicativeStudyRoute> {
  List<bool> stackVisibility = [true, true, true, true, true, true];
  int hideIndex = 0;
  double _sliderValue = 2000;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: "Verbomatique",
      theme: CustomTheme.lightTheme,
      home: SafeArea(
        key: UniqueKey(),
        child: Scaffold(
          key: UniqueKey(),
          appBar: VerbIndicativeStudyFormAppbar().asWidget(context),
          body: Column(
            key: UniqueKey(),
            children: [
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Stack(
                  key: Key('cardStack'),
                  fit: StackFit.loose,
                  children: _cardStack(context),
                ),
              ),
              if (hideIndex > 0)
                Padding(
                  key: UniqueKey(),
                  padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                  child: FloatingActionButton(
                    heroTag: UniqueKey(),
                    key: Key('ResetButton'),
                    onPressed: () {
                      setState(() {
                        stackVisibility = [true, true, true, true, true, true];
                        hideIndex = 0;
                      });
                    },
                    child: Icon(
                      Icons.refresh,
                      key: UniqueKey(),
                    ),
                  ),
                )
              else
                Padding(
                  key: UniqueKey(),
                  padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                  child: FloatingActionButton(
                    heroTag: UniqueKey(),
                    key: Key('PlayButton'),
                    onPressed: () {
                      Timer.periodic(
                          Duration(milliseconds: _sliderValue.toInt()),
                          (timer) {
                        if (hideIndex < 5) {
                          setState(() {
                            stackVisibility[hideIndex++] = false;
                          });
                        } else {
                          timer.cancel();
                        }
                      });
                    },
                    child: Icon(
                      Icons.play_arrow,
                      key: UniqueKey(),
                    ),
                  ),
                ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Row(
                  key: UniqueKey(),
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Icon(
                      Icons.access_alarm_rounded,
                      key: UniqueKey(),
                    ),
                    Slider(
                        key: Key('flashcard_slider'),
                        min: 1000.0,
                        max: 3000.0,
                        divisions: 6,
                        value: _sliderValue,
                        onChanged: (double value) {
                          setState(() {
                            _sliderValue = value;
                          });
                        }),
                    Icon(
                      Icons.add_alarm_rounded,
                      key: UniqueKey(),
                    )
                  ],
                ),
              ),
            ],
          ),
          floatingActionButton: Visibility(
            key: Key('flashcard_forward_button_visibility'),
            visible: (hideIndex == 5),
            child: FloatingActionButton(
              heroTag: UniqueKey(),
              key: Key('flashcard_forward_button'),
              onPressed: () {
                Navigator.pushNamed(
                    context, '/verbIndicativeFlashcardModeTestRoute');
              },
              child: Icon(
                Icons.arrow_forward,
                key: UniqueKey(),
              ),
            ),
          ),
        ),
      ),
    );
  }

  List<Widget> _cardStack(BuildContext context) {
    List<Widget> _result = [];

    for (int i = 5; i >= 0; i--) {
      if (stackVisibility[i]) {
        _result.add(_card(context, i));
      }
    }

    return _result;
  }

  Widget _card(BuildContext context, int person) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return Card(
        elevation: 10.0,
        margin: EdgeInsets.fromLTRB(10, 10, 10, 10),
        child: ListTile(
          title: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Text(
                    _adaptedPronoun("fr", testModel.pronouns[person],
                        testModel.verb.indicative[person]),
                    style: TextStyle(
                      color: Colors.blue,
                      fontSize: 25,
                    )),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Text(testModel.verb.indicative[person],
                    style: TextStyle(
                      color: Colors.green,
                      fontSize: 25,
                    )),
              ),
            ],
          ),
        ),
      );
    });
  }

  String _adaptedPronoun(String isoLang, String pronoun, String actual) {
    //TODO refactor with Strategy or the likes
    if ("fr" == isoLang) {
      if ("" != actual &&
          "je" == pronoun &&
          (actual.substring(0, 1) == 'a' ||
              actual.substring(0, 1) == 'e' ||
              actual.substring(0, 1) == 'i' ||
              actual.substring(0, 1) == 'o' ||
              actual.substring(0, 1) == 'u')) {
        return "j\'";
      }
    }
    return pronoun;
  }
}

==> cramr_ui_lib-0.0.6.tar.gz: lib/routes/verb_indicative_study_flashcard_mode_form_state.dart <==
import 'dart:async';

import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_form_appbar.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_route.dart';
import 'package:cramr_ui_lib/theme/custom_theme.dart';
import 'package:cramr_ui_lib/util/pronoun_decorator.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class VerbIndicativeStudyFlashcardModeFormState
    extends State<VerbIndicativeStudyRoute> {
  List<bool> stackVisibility = [true, true, true, true, true, true];
  int hideIndex = 0;
  double _sliderValue = 2000;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: "Verbomatique",
      theme: CustomTheme.lightTheme,
      home: SafeArea(
        key: UniqueKey(),
        child: Scaffold(
          key: UniqueKey(),
          appBar: VerbIndicativeStudyFormAppbar().asWidget(context),
          body: Column(
            key: UniqueKey(),
            children: [
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Stack(
                  key: Key('cardStack'),
                  fit: StackFit.loose,
                  children: _cardStack(context),
                ),
              ),
              if (hideIndex > 0)
                Padding(
                  key: UniqueKey(),
                  padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                  child: FloatingActionButton(
                    heroTag: UniqueKey(),
                    key: Key('ResetButton'),
                    onPressed: () {
                      setState(() {
                        stackVisibility = [true, true, true, true, true, true];
                        hideIndex = 0;
                      });
                    },
                    child: Icon(
                      Icons.refresh,
                      key: UniqueKey(),
                    ),
                  ),
                )
              else
                Padding(
                  key: UniqueKey(),
                  padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                  child: FloatingActionButton(
                    heroTag: UniqueKey(),
                    key: Key('PlayButton'),
                    onPressed: () {
                      Timer.periodic(
                          Duration(milliseconds: _sliderValue.toInt()),
                          (timer) {
                        if (hideIndex < 5) {
                          setState(() {
                            stackVisibility[hideIndex++] = false;
                          });
                        } else {
                          timer.cancel();
                        }
                      });
                    },
                    child: Icon(
                      Icons.play_arrow,
                      key: UniqueKey(),
                    ),
                  ),
                ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Row(
                  key: UniqueKey(),
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Icon(
                      Icons.access_alarm_rounded,
                      key: UniqueKey(),
                    ),
                    Slider(
                        key: Key('flashcard_slider'),
                        min: 1000.0,
                        max: 3000.0,
                        divisions: 6,
                        value: _sliderValue,
                        onChanged: (double value) {
                          setState(() {
                            _sliderValue = value;
                          });
                        }),
                    Icon(
                      Icons.add_alarm_rounded,
                      key: UniqueKey(),
                    )
                  ],
                ),
              ),
            ],
          ),
          floatingActionButton: Visibility(
            key: Key('flashcard_forward_button_visibility'),
            visible: (hideIndex == 5),
            child: FloatingActionButton(
              heroTag: UniqueKey(),
              key: Key('flashcard_forward_button'),
              onPressed: () {
                Navigator.pushNamed(
                    context, '/verbIndicativeFlashcardModeTestRoute');
              },
              child: Icon(
                Icons.arrow_forward,
                key: UniqueKey(),
              ),
            ),
          ),
        ),
      ),
    );
  }

  List<Widget> _cardStack(BuildContext context) {
    List<Widget> _result = [];

    for (int i = 5; i >= 0; i--) {
      if (stackVisibility[i]) {
        _result.add(_card(context, i));
      }
    }

    return _result;
  }

  Widget _card(BuildContext context, int person) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return Card(
        elevation: 10.0,
        margin: EdgeInsets.fromLTRB(10, 10, 10, 10),
        child: ListTile(
          title: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Text(
                    PronounDecorator.decoratedPronoun(
                        "fr",
                        testModel.pronouns[person],
                        testModel.verb.indicative[person]),
                    style: TextStyle(
                      color: Colors.blue,
                      fontSize: 25,
                    )),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 30, 10, 30),
                child: Text(testModel.verb.indicative[person],
                    style: TextStyle(
                      color: Colors.green,
                      fontSize: 25,
                    )),
              ),
            ],
          ),
        ),
      );
    });
  }
}
